//
// C++ Interface: k9settings
//
// Description: 
//
//
// Author: Jean-Michel PETIT <k9copy@free.fr>, (C) 2006
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef K9SETTINGS_H
#define K9SETTINGS_H

#include "k9common.h"
#include "tdeconfigdlg.h"
#include "k9prefdvd.h"
#include "k9prefmpeg4.h"
#include "k9prefmencoder.h"
#include "k9prefpreview.h"
#include "k9prefauthor.h"
#include <kdialogbase.h>

/**
	@author Jean-Michel PETIT <k9copy@free.fr>
*/
class k9settings:public KDialogBase{
TQ_OBJECT
  
public:
    k9settings(TQWidget *parent,const TQString &caption);

    virtual ~k9settings();

private:
    kConfigDlg *m_configDlg;
    k9prefDVD *m_prefDVD;
    k9prefMPEG4 *m_prefMPEG4;
    k9prefMencoder *m_prefMencoder;
    k9prefPreview *m_prefPreview;
    k9prefAuthor *m_prefAuthor;
private slots:
    void slotOkClicked();
    void slotApplyClicked();
};

#endif
